==> xwiki-rendering-api-3.0-milestone-3-sources.jar: org/xwiki/rendering/internal/parser/reference/AttachmentResourceReferenceTypeParser.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.parser.reference;

import org.xwiki.component.annotation.Component;
import org.xwiki.rendering.listener.reference.ResourceType;

/**
 * Parses a resource reference to an attachment.
 * 
 * @version $Id: AttachmentResourceReferenceTypeParser.java 31687 2010-10-08 19:37:36Z vmassol $
 * @since 2.5RC1
 */
@Component("attach")
public class AttachmentResourceReferenceTypeParser extends AbstractURIResourceReferenceTypeParser
{
    /**
     * {@inheritDoc}
     * @see AbstractURIResourceReferenceTypeParser#getType()
     */
    public ResourceType getType()
    {
        return ResourceType.ATTACHMENT;
    }
}

==> xwiki-rendering-api-3.2-milestone-3-sources.jar: org/xwiki/rendering/internal/parser/reference/AttachmentResourceReferenceTypeParser.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.internal.parser.reference;

import javax.inject.Named;
import javax.inject.Singleton;

import org.xwiki.component.annotation.Component;
import org.xwiki.rendering.listener.reference.ResourceType;

/**
 * Parses a resource reference to an attachment.
 * 
 * @version $Id$
 * @since 2.5RC1
 */
@Component
@Named("attach")
@Singleton
public class AttachmentResourceReferenceTypeParser extends AbstractURIResourceReferenceTypeParser
{
    /**
     * {@inheritDoc}
     * @see AbstractURIResourceReferenceTypeParser#getType()
     */
    public ResourceType getType()
    {
        return ResourceType.ATTACHMENT;
    }
}
